python-shaarli-client
=====================

.. image:: https://github.com/shaarli/python-shaarli-client/actions/workflows/ci.yml/badge.svg
   :target: https://github.com/nodiscc/python-shaarli-client/actions
   :alt: Github Actions build status

.. image:: https://readthedocs.org/projects/python-shaarli-client/badge/?version=latest
   :target: http://python-shaarli-client.readthedocs.org/en/latest/?badge=latest
   :alt: Documentation Status

A Python 3 Command-Line Interface to interact with a Shaarli instance.
